@@ -9,14 +9,14 @@ def ZipFolder(folder_path: str):
     :param folder_path: Path to the folder to be compressed
     :return: The path to the generated zip file
     """
-    zip_file_path = "{}.zip".format(folder_path.strip('/\\'))
+    zip_file_path = "{}.zip".format(folder_path.strip('/'))
     if os.path.exists(zip_file_path):
         os.remove(zip_file_path)
     zip_file = zipfile.ZipFile(zip_file_path, mode='x', compression=zipfile.ZIP_DEFLATED)
     for dir_path, dir_names, file_names in os.walk(folder_path):
         for file in file_names:
-            file_path = '\\'.join([dir_path, file])
-            zip_path = '/'.join(file_path.split('\\')[1:])
+            file_path = '/'.join([dir_path, file])
+            zip_path = '/'.join(file_path.split('/')[1:])
             zip_file.write(file_path, arcname=zip_path)
     zip_file.close()
     return zip_file_path
